/* $Id: detmon_opt_lg.c,v 1.19 2011/03/01 16:54:21 amodigli Exp $
 *
 * This file is part of the DETMON Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * $Author: amodigli $
 * $Date: 2011/03/01 16:54:21 $
 * $Revision: 1.19 $
 * $Name: HEAD $
 */
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

/*----------------------------------------------------------------------------
                             Includes
 ----------------------------------------------------------------------------*/

#include <cpl.h>

#include "irplib_detmon.h"
#include "irplib_detmon_lg.h"
#include "irplib_plugin.h"

/* Define here the DO.CATG keywords */
#define DETMON_OPT_LG_ON_RAW                    "ON_RAW"
#define DETMON_OPT_LG_OFF_RAW			"OFF_RAW"

#define RECIPE_NAME "detmon_opt_lg"

#define OPT FALSE

/*----------------------------------------------------------------------------
				Functions prototypes
 ----------------------------------------------------------------------------*/

IRPLIB_RECIPE_DEFINE(detmon_opt_lg, DETMON_BINARY_VERSION,
                     irplib_detmon_lg_fill_parlist_opt_default(recipe->parameters,
                                               "detmon_opt_lg", "detmon"),
                     "Lander de Bilbao", "lbilbao@eso.org", "2007", 
                     "Linearity/Gain recipe for the optical domain",
                     irplib_detmon_lg_get_description("detmon_opt_lg", "DETMON",
                                                      DETMON_OPT_LG_ON_RAW,
                                                      DETMON_OPT_LG_OFF_RAW));

/*---------------------------------------------------------------------------*/
/*
  @brief    Interpret the command line options and execute the data processing
  @param    frameset    the frames list
  @param    parlist     the parameters list
  @return   0 if everything is ok
 */
/*---------------------------------------------------------------------------*/

static int detmon_opt_lg(cpl_frameset            * frameset,
                         const cpl_parameterlist * parlist)
{
    cpl_propertylist * lintbl = 
	irplib_detmon_fill_prolist("DET_LIN_INFO", "REDUCED", "TECH", CPL_FALSE);

    cpl_propertylist * gaintbl = 
	irplib_detmon_fill_prolist("GAIN_INFO",    "REDUCED", "TECH", CPL_FALSE);

    cpl_propertylist * coeffscube = 
	irplib_detmon_fill_prolist("COEFFS_CUBE",  "REDUCED", "TECH", CPL_FALSE);

    cpl_propertylist * bpm = 
	irplib_detmon_fill_prolist("BP_MAP_NL",    "REDUCED", "TECH", CPL_FALSE);

    cpl_propertylist * corr = 
	irplib_detmon_fill_prolist("AUTOCORR",     "REDUCED", "TECH", CPL_FALSE);

    cpl_propertylist * diff_flat = 
	irplib_detmon_fill_prolist("DIFF_FLAT",    "REDUCED", "TECH", CPL_FALSE);

    const cpl_error_code error = irplib_detmon_lg(frameset,
                                                  parlist,
                                                  DETMON_OPT_LG_ON_RAW,
                                                  DETMON_OPT_LG_OFF_RAW,
                                                  RECIPE_NAME,
                                                  PACKAGE_TARNAME,
						  REGEXP,
                                                  lintbl, gaintbl, coeffscube,
						  bpm, corr, diff_flat,
                                                  PACKAGE "/" PACKAGE_VERSION,
                                                  NULL, NULL, OPT);

    cpl_propertylist_delete(lintbl);
    cpl_propertylist_delete(gaintbl);
    cpl_propertylist_delete(coeffscube);
    cpl_propertylist_delete(bpm);
    cpl_propertylist_delete(corr);
    cpl_propertylist_delete(diff_flat);

    /* Propagate the error, if any */
    cpl_ensure_code(!error, error);

    return CPL_ERROR_NONE;
}
